2023-12-25 Version: 1.0.15
- Generated python 2022-02-22 for Ess.

2023-12-06 Version: 1.0.14
- Generated python 2022-02-22 for Ess.

2023-12-04 Version: 1.0.13
- Generated python 2022-02-22 for Ess.

2023-11-17 Version: 1.0.12
- Generated python 2022-02-22 for Ess.

2023-10-18 Version: 1.0.11
- Generated python 2022-02-22 for Ess.

2023-10-18 Version: 1.0.10
- Generated python 2022-02-22 for Ess.

2023-09-19 Version: 1.0.9
- Generated python 2022-02-22 for Ess.

2023-08-23 Version: 1.0.8
- Generated python 2022-02-22 for Ess.

2023-07-20 Version: 1.0.7
- DescribeScalingInstances support creationTypes.

2023-04-19 Version: 1.0.6
- Configuration support LoginAsNonRoot .

2023-03-09 Version: 1.0.5
- Fix the incompatibility of some parameters in the SDK .

2023-02-12 Version: 1.0.4
- CreateScalingGroup and DescribeScalingGroup support NLB server group and new open api AttachServerGroups and DetachServerGroups .

2023-01-13 Version: 1.0.3
- CreateScalingGroup and DescribeScalingGroup support resourcegroup.

2022-10-14 Version: 1.0.2
- Support user custom removal  function policy.

2022-10-14 Version: 1.0.1
- LifecycleHook support disable and enable, ScaleWithAdjustment support scale by instance type.

2022-09-09 Version: 1.0.0
- Ess Tea 2022 SDK release.

